#
# spec file for package zcfan
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zcfan
Version:        1.4.0
Release:        1.2
Summary:        Zero-configuration fan control daemon for ThinkPads
License:        MIT
URL:            https://github.com/cdown/zcfan
Source:         https://github.com/cdown/zcfan/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         move_executable_to_sbin.patch
%if 0%{?suse_version} < 1550
BuildRequires:  gcc11
%else
BuildRequires:  gcc >= 11
%endif
BuildRequires:  make
Conflicts:      thinkfan

%description
Zero-configuration fan control daemon for ThinkPads with watchdog
support and automatic temperature- and time-based hysteresis (no
bouncing between fan levels).

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1550
export CC=gcc-11
%endif
%make_build CFLAGS="%{optflags} -fPIE" LDFLAGS="%{optflags} -pie"

%install
%make_install prefix=%{_prefix}

%pre
%service_add_pre zcfan.service

%post
%service_add_post zcfan.service

%preun
%service_del_preun zcfan.service

%postun
%service_del_postun zcfan.service

%files
%license LICENSE
%doc README.md
%{_sbindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_unitdir}/%{name}.service

%changelog
* Tue Dec 31 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.4.0:
  * Mark zcfan.service as conflicting with thinkfan.service
  * Make fan levels configurable in config
  * On watchdog timeout, write to watchdog to avoid spinup on some models
  * Detect suspend and handle fan level reset
- mark as conflicts with thinkfan package
* Thu Feb 29 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.3.0:
  * Add watchdog_secs directive to config (thanks @errge)
  * Use full-speed for max_temp if supported
  * Only do temperature file globbing once
    + This should be a noop, but please file an issue if it causes a problem.
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Mon Sep  4 2023 Andrea Manzini <andrea.manzini@suse.com>
- Add move_executable_to_sbin.patch
* Sat Sep  2 2023 Andrea Manzini <andrea.manzini@suse.com>
- Fixed compilation on 15.4 and 15.5
- build with -fPIE
* Fri Sep  1 2023 Jan Engelhardt <jengelh@inai.de>
- Trim description to what's relevant for the end-user
- Remove redundant DESTDIR argument in make_install
- Source archive with dash like normal packages
* Fri Sep  1 2023 Andrea Manzini <andrea.manzini@suse.com>
- version 1.2.1:
  * first packaged release
